@@ -1,7 +1,7 @@
 // vim: set tabstop=4 shiftwidth=4 noexpandtab
 /*
 Gwenview - A simple image viewer for KDE
-Copyright 2006 Aurelien Gateau <aurelien.gateau@free.fr>
+Copyright 2006 Aurelien Gateau <agateau@kde.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -33,11 +33,9 @@ namespace Gwenview {
 
 namespace MimeTypeUtils {
 
-GWENVIEWLIB_EXPORT const QStringList& dirMimeTypes();
 GWENVIEWLIB_EXPORT const QStringList& rasterImageMimeTypes();
 GWENVIEWLIB_EXPORT const QStringList& svgImageMimeTypes();
 GWENVIEWLIB_EXPORT const QStringList& imageMimeTypes();
-GWENVIEWLIB_EXPORT const QStringList& videoMimeTypes();
 
 GWENVIEWLIB_EXPORT QString urlMimeType(const KUrl&);
 
@@ -46,7 +44,17 @@ GWENVIEWLIB_EXPORT QString urlMimeType(const KUrl&);
  */
 GWENVIEWLIB_EXPORT QString urlMimeTypeByContent(const KUrl&);
 
-enum Kind { KIND_UNKNOWN, KIND_DIR, KIND_ARCHIVE, KIND_FILE, KIND_RASTER_IMAGE, KIND_SVG_IMAGE };
+enum Kind {
+	KIND_UNKNOWN      = 0,
+	KIND_DIR          = 1,
+	KIND_ARCHIVE      = 1 << 2,
+	KIND_FILE         = 1 << 3,
+	KIND_RASTER_IMAGE = 1 << 4,
+	KIND_SVG_IMAGE    = 1 << 5,
+	KIND_VIDEO        = 1 << 6
+};
+Q_DECLARE_FLAGS(Kinds, Kind)
+
 GWENVIEWLIB_EXPORT Kind fileItemKind(const KFileItem&);
 GWENVIEWLIB_EXPORT Kind urlKind(const KUrl&);
 GWENVIEWLIB_EXPORT Kind mimeTypeKind(const QString& mimeType);
@@ -55,4 +63,6 @@ GWENVIEWLIB_EXPORT Kind mimeTypeKind(const QString& mimeType);
 
 } // namespace Gwenview
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(Gwenview::MimeTypeUtils::Kinds)
+
 #endif /* MIMETYPEUTILS_H */
