@@ -21,19 +21,22 @@
 
 */
 #include <qlayout.h>
-#include <qgrid.h>
+#include <q3grid.h>
 #include <qlabel.h>
-#include <qvgroupbox.h>
+#include <Q3GroupBox>
 #include <qcheckbox.h>
 #include <qradiobutton.h>
 #include <qlineedit.h>
 #include <qcombobox.h>
 #include <qslider.h>
-#include <qvbuttongroup.h>
-#include <qhbuttongroup.h>
-#include <qvbox.h>
+#include <Q3ButtonGroup>
+
+#include <kvbox.h>
 #include <qtabwidget.h>
-#include <qwhatsthis.h>
+
+//Added by qt3to4:
+#include <QFrame>
+#include <QVBoxLayout>
 
 #include <klocale.h>
 
@@ -44,22 +47,29 @@ KameraConfigDialog::KameraConfigDialog(Camera */*camera*/,
 					CameraWidget *widget,
 					QWidget *parent,
 					const char *name) :
-KDialogBase(parent, name, true, QString::null, Ok|Cancel, Ok ),
-m_widgetRoot(widget)
+    KDialog(parent),
+    m_widgetRoot(widget)
 {
-    QFrame *main = makeMainWidget();
-	QVBoxLayout *topLayout = new QVBoxLayout(main, 0, spacingHint());
-	topLayout->setAutoAdd(true);
+    setButtons( Ok|Cancel );
+    setDefaultButton( Ok );
+    setModal( true );
 
-	m_tabWidget = 0;
+    QFrame *main = new QFrame( this );
+    setMainWidget( main );
+    QVBoxLayout *topLayout = new QVBoxLayout(main);
+    topLayout->setSpacing(spacingHint());
+    topLayout->setMargin(0);
 
-	appendWidget(main, widget);
+    m_tabWidget = 0;
+
+    appendWidget(main, widget);
+    connect(this,SIGNAL(okClicked()),this,SLOT(slotOk()));
 }
 
 void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
 {
 	QWidget *newParent = parent;
-	
+
 	CameraWidgetType widget_type;
 	const char *widget_name;
 	const char *widget_info;
@@ -71,7 +81,7 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
 	gp_widget_get_label(widget, &widget_label);
 	gp_widget_get_info(widget, &widget_info);
 	gp_widget_get_name(widget, &widget_name);
-	
+
 	QString whats_this = QString::fromLocal8Bit(widget_info);	// gphoto2 doesn't seem to have any standard for i18n
 
 	// Add this widget to parent
@@ -79,39 +89,42 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
 	case GP_WIDGET_WINDOW:
 		{
 			setCaption(widget_label);
-			
+
 			break;
 		}
 	case GP_WIDGET_SECTION:
 		{
-			if (!m_tabWidget)
+			if (!m_tabWidget) {
 				m_tabWidget = new QTabWidget(parent);
+				parent->layout()->addWidget(m_tabWidget);
+			}
 			QWidget *tab = new QWidget(m_tabWidget);
 			// widgets are to be aligned vertically in the tab
 			QVBoxLayout *tabLayout = new QVBoxLayout(tab, marginHint(),
 				spacingHint());
 			m_tabWidget->insertTab(tab, widget_label);
-			QVBox *tabContainer = new QVBox(tab);
+			KVBox *tabContainer = new KVBox(tab);
 			tabContainer->setSpacing(spacingHint());
 			tabLayout->addWidget(tabContainer);
 			newParent = tabContainer;
 
 			tabLayout->addStretch();
-		
+
 			break;
 		}
 	case GP_WIDGET_TEXT:
 		{
 			gp_widget_get_value(widget, &widget_value_string);
 
-			QGrid *grid = new QGrid(2, Horizontal, parent);
+			Q3Grid *grid = new Q3Grid(2, Qt::Horizontal, parent);
+			parent->layout()->addWidget(grid);
 			grid->setSpacing(spacingHint());
-			new QLabel(QString::fromLocal8Bit( widget_label )+":", grid);
+			new QLabel(QString::fromLocal8Bit( widget_label )+':', grid);
 			QLineEdit *lineEdit = new QLineEdit(widget_value_string, grid);
 			m_wmap.insert(widget, lineEdit);
 
 			if (!whats_this.isEmpty())
-				QWhatsThis::add(grid, whats_this);
+				grid->setWhatsThis( whats_this);
 
 			break;
 		}
@@ -122,48 +135,51 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
 			float widget_increment;
 			gp_widget_get_range(widget, &widget_low, &widget_high, &widget_increment);
 			gp_widget_get_value(widget, &widget_value_float);
-	
-			QGroupBox *groupBox = new QVGroupBox(widget_label, parent);
+
+			Q3GroupBox *groupBox = new Q3GroupBox(1, Qt::Horizontal,widget_label, parent);
+			parent->layout()->addWidget(groupBox);
 			QSlider *slider = new QSlider(
 				( int )widget_low,
 				( int )widget_high,
 				( int )widget_increment,
 				( int )widget_value_float,
-				QSlider::Horizontal,
+				Qt::Horizontal,
 				groupBox );
 			m_wmap.insert(widget, slider);
-		
+
 			if (!whats_this.isEmpty())
-				QWhatsThis::add(groupBox, whats_this);
-		
+				groupBox->setWhatsThis( whats_this);
+
 			break;
 		}
 	case GP_WIDGET_TOGGLE:
 		{
 			gp_widget_get_value(widget, &widget_value_int);
-		
+
 			QCheckBox *checkBox = new QCheckBox(widget_label, parent);
+			parent->layout()->addWidget(checkBox);
 			checkBox->setChecked(widget_value_int);
 			m_wmap.insert(widget, checkBox);
 
 			if (!whats_this.isEmpty())
-				QWhatsThis::add(checkBox, whats_this);
+				checkBox->setWhatsThis( whats_this);
 
 			break;
 		}
 	case GP_WIDGET_RADIO:
 		{
 			gp_widget_get_value(widget, &widget_value_string);
-	
+
 			int count = gp_widget_count_choices(widget);
 
 			// for less than 5 options, align them horizontally
-			QButtonGroup *buttonGroup;
+			Q3ButtonGroup *buttonGroup;
 			if (count > 4)
-				buttonGroup = new QVButtonGroup(widget_label, parent);
+				buttonGroup = new Q3VButtonGroup(widget_label, parent);
 			else
-				buttonGroup = new QHButtonGroup(widget_label, parent);
-			
+				buttonGroup = new Q3HButtonGroup(widget_label, parent);
+			parent->layout()->addWidget(buttonGroup);
+
 			for(int i = 0; i < count; ++i) {
 				const char *widget_choice;
 				gp_widget_get_choice(widget, i, &widget_choice);
@@ -175,15 +191,16 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
 			m_wmap.insert(widget, buttonGroup);
 
 			if (!whats_this.isEmpty())
-				QWhatsThis::add(buttonGroup, whats_this);
+				buttonGroup->setWhatsThis( whats_this);
 
 			break;
 		}
 	case GP_WIDGET_MENU:
 		{
 			gp_widget_get_value(widget, &widget_value_string);
-	
-			QComboBox *comboBox = new QComboBox(FALSE, parent);
+
+			QComboBox *comboBox = new QComboBox(parent);
+			parent->layout()->addWidget(comboBox);
 			comboBox->clear();
 			for(int i = 0; i < gp_widget_count_choices(widget); ++i) {
 				const char *widget_choice;
@@ -196,7 +213,7 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
 			m_wmap.insert(widget, comboBox);
 
 			if (!whats_this.isEmpty())
-				QWhatsThis::add(comboBox, whats_this);
+				comboBox->setWhatsThis( whats_this);
 
 			break;
 		}
@@ -206,14 +223,16 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
 			// I can't see a way of implementing this. Since there is
 			// no way of telling which button sent you a signal, we
 			// can't map to the appropriate widget->callback
-			new QLabel(i18n("Button (not supported by KControl)"), parent);
-	
+			QLabel *label = new QLabel(i18n("Button (not supported by KControl)"), parent);
+			parent->layout()->addWidget(label);
+
 			break;
 		}
 	case GP_WIDGET_DATE:
 		{
 			// TODO
-			new QLabel(i18n("Date (not supported by KControl)"), parent);
+			QLabel * label = new QLabel(i18n("Date (not supported by KControl)"), parent);
+			parent->layout()->addWidget(label);
 
 			break;
 		}
@@ -227,7 +246,7 @@ void KameraConfigDialog::appendWidget(QWidget *parent, CameraWidget *widget)
 		gp_widget_get_child(widget, i, &widget_child);
 		appendWidget(newParent, widget_child);
 	}
-	
+
 	// Things that must be done after all children were added
 /*
 	switch (widget_type) {
@@ -255,8 +274,8 @@ void KameraConfigDialog::updateWidgetValue(CameraWidget *widget)
 	case GP_WIDGET_TEXT:
 		{
 			QLineEdit *lineEdit = static_cast<QLineEdit *>(m_wmap[widget]);
-			gp_widget_set_value(widget, (void *)lineEdit->text().local8Bit().data());
-	
+			gp_widget_set_value(widget, (void *)lineEdit->text().toLocal8Bit().data());
+
 			break;
 		}
 	case GP_WIDGET_RANGE:
@@ -264,7 +283,7 @@ void KameraConfigDialog::updateWidgetValue(CameraWidget *widget)
 			QSlider *slider = static_cast<QSlider *>(m_wmap[widget]);
 			float value_float = slider->value();
 			gp_widget_set_value(widget, (void *)&value_float);
-			
+
 			break;
 		}
 	case GP_WIDGET_TOGGLE:
@@ -272,21 +291,21 @@ void KameraConfigDialog::updateWidgetValue(CameraWidget *widget)
 			QCheckBox *checkBox = static_cast<QCheckBox *>(m_wmap[widget]);
 			int value_int = checkBox->isChecked() ? 1 : 0;
 			gp_widget_set_value(widget, (void *)&value_int);
-			
+
 			break;
 		}
 	case GP_WIDGET_RADIO:
 		{
-			QButtonGroup *buttonGroup = static_cast<QVButtonGroup *>(m_wmap[widget]);
-			gp_widget_set_value(widget, (void *)buttonGroup->selected()->text().local8Bit().data());
+			Q3ButtonGroup *buttonGroup = static_cast<Q3VButtonGroup *>(m_wmap[widget]);
+			gp_widget_set_value(widget, (void *)buttonGroup->selected()->text().toLocal8Bit().data());
 
 			break;
 		}
 	case GP_WIDGET_MENU:
 		{
 			QComboBox *comboBox = static_cast<QComboBox *>(m_wmap[widget]);
-			gp_widget_set_value(widget, (void *)comboBox->currentText().local8Bit().data());
-	
+			gp_widget_set_value(widget, (void *)comboBox->currentText().toLocal8Bit().data());
+
 			break;
 		}
 	case GP_WIDGET_BUTTON:
@@ -298,7 +317,7 @@ void KameraConfigDialog::updateWidgetValue(CameraWidget *widget)
 			break;
 		}
 	}
-	
+
 	// Copy child widget values
 	for(int i = 0; i < gp_widget_count_children(widget); ++i) {
 		CameraWidget *widget_child;
