@@ -77,6 +77,7 @@ KSaneWidgetPrivate::KSaneWidgetPrivate()
     m_dataSize      = 0;
     m_readStatus    = READ_READY;
     m_isPreview     = false;
+    m_timeSinceUpd.restart();
     m_saneHandle    = 0;
     m_readThread    = 0;
     m_splitGamChB   = 0;
@@ -621,10 +622,10 @@ void KSaneWidgetPrivate::scanPreview()
     }
     
     // set the resopution to 100 dpi and increase if necessary
-    dpi = 0.0;
+    dpi = 25.0;
     do {
         // Increase the dpi value
-        dpi += 100.0;
+        dpi += 25.0;
         if (m_optRes != 0) {
             m_optRes->setValue(dpi);
         }
@@ -805,9 +806,9 @@ void KSaneWidgetPrivate::startScan()
             (m_previewImg.width() != m_params.pixels_per_line))
         {
             m_previewImg = QImage(m_params.pixels_per_line,
-                                      m_params.lines,
-                                      QImage::Format_RGB32);
-                                      m_previewImg.fill(0xFFFFFFFF);
+                                  m_params.lines,
+                                  QImage::Format_RGB32);
+            m_previewImg.fill(0xFFFFFFFF);
         }
         
         // update the size of the preview widget.
@@ -849,7 +850,7 @@ void KSaneWidgetPrivate::scanDone()
         if (m_optBrX != 0) m_optBrX->restoreSavedData();
         if (m_optBrY != 0) m_optBrY->restoreSavedData();
         if (m_optPreview != 0) m_optPreview->restoreSavedData();
-        
+
         if (m_autoSelect) {
             m_previewViewer->findSelections();
         }
@@ -896,6 +897,8 @@ void KSaneWidgetPrivate::scanDone()
         }
     }
     
+    sane_cancel(m_saneHandle);
+
     setBusy(false);
     if (m_optTlX != 0) m_optTlX->restoreSavedData();
     if (m_optTlY != 0) m_optTlY->restoreSavedData();
@@ -906,7 +909,6 @@ void KSaneWidgetPrivate::scanDone()
     m_readStatus = READ_READY;
     
     if (error) {
-        sane_cancel(m_saneHandle);
         emit scanDone(KSaneWidget::ErrorGeneral, "");
     }
     else {
@@ -917,7 +919,6 @@ void KSaneWidgetPrivate::scanDone()
 
 void KSaneWidgetPrivate::scanCancel()
 {
-    sane_cancel(m_saneHandle);
     m_readStatus = READ_CANCEL;
     m_progressBar->setValue(0);
 }
@@ -1021,6 +1022,14 @@ void KSaneWidgetPrivate::processData()
             return;
     }
     
+    // copy the data to the buffer
+    if (m_isPreview) {
+        copyToPreview((int)m_readThread->readBytes);
+    }
+    else {
+        copyToScanData((int)m_readThread->readBytes);
+    }
+    
     // update progressBar
     if (m_params.lines > 0) {
         long int new_progress;
@@ -1037,8 +1046,9 @@ void KSaneWidgetPrivate::processData()
         
         if (new_progress != m_progressBar->value()) {
             //kDebug(51004) << new_progress << m_frameRead << m_dataSize;
-            if (m_isPreview) {
+            if (m_isPreview && (m_timeSinceUpd.elapsed() > 300)) { // update the preview only every 300ms
                 m_previewViewer->updateImage();
+                m_timeSinceUpd.restart();
             }
             m_progressBar->setValue((int)new_progress);
             emit scanProgress(new_progress);
@@ -1046,14 +1056,6 @@ void KSaneWidgetPrivate::processData()
         
     }
     
-    // copy the data to the buffer
-    if (m_isPreview) {
-        copyToPreview((int)m_readThread->readBytes);
-    }
-    else {
-        copyToScanData((int)m_readThread->readBytes);
-    }
-    
     if (m_readStatus == READ_ON_GOING) {
         m_readThread->start();
     }
